Grid trait abstracting over grid-like containers along with two implementors BoolGrid and SimpleGrid.
Structs
- Bool
Grid - Compact bitwise implementation of a [ValGrid] of bool’s.
- Simple
Grid - Generic Grid implementation.
- Simple
Value Grid - Generic ValueGrid implementation for Clone and Copy items.
Traits
- Grid
- The Grid trait abstracts over containers of items laid out in a rectangle with a certain width and height. Elements are accessed by reference using get, get_mut and related functions.
- Value
Grid - The ValueGrid trait abstracts over containers of Clone and Copy items laid out in a rectangle with a certain width and height.